@@ -21,6 +21,9 @@ from tensorflow.keras.layers import Input, Flatten
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
+# CNN2SNN imports
+from cnn2snn import load_quantized_model
+
 from ..quantization_blocks import conv_block, dense_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
@@ -68,29 +71,6 @@ def vgg_cifar10(input_shape,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    # Check weights
-    if not (weights in {None, 'cifar10'} or os.path.exists(weights)):
-        raise ValueError('The `weights` argument should be either '
-                         '`None` (random initialization) '
-                         'or `cifar10` to load weights over http '
-                         'or the path to the weights file to be loaded.')
-
-    # Check if imagenet pretrained weights are compatible with given arguments
-    if weights == 'cifar10':
-        quant_params = (weight_quantization, activ_quantization,
-                        input_weight_quantization)
-        if classes != 10:
-            raise ValueError("If 'weights' is 'cifar10', classes should be 10")
-        if quant_params != (2, 2, 2):
-            raise ValueError(
-                "If 'weights' is 'cifar10', quantization parameters "
-                "(weight_quantization, activ_quantization, "
-                " input_weight_quantization) must be (2, 2, 2); "
-                f" got quantization parameters={quant_params}")
-        if input_shape != (32, 32, 3):
-            raise ValueError("If 'weights' is 'cifar10', input shape must be "
-                             f" (32,32,3) ; got input_shape={input_shape}")
-
     img_input = Input(shape=input_shape)
 
     x = conv_block(img_input,
@@ -191,14 +171,15 @@ def vgg_cifar10(input_shape,
     model = Model(img_input, x, name='vgg_cifar10')
 
     # Load weights
-    if weights == 'cifar10':
-        model_name = (f'vgg_like_cifar10_wq{weight_quantization}'
-                      f'_aq{activ_quantization}.hdf5')
-        weights_path = get_file(fname=model_name,
-                                origin=BASE_WEIGHT_PATH + model_name,
-                                cache_subdir='models')
-        model.load_weights(weights_path)
-    elif weights is not None:
-        model.load_weights(weights)
+    if weights is not None:
+        model.load_weights(weights, by_name=True)
 
     return model
+
+
+def vgg_cifar10_pretrained():
+    model_name = 'vgg_cifar10_wq2_aq2.hdf5'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
\ No newline at end of file
