@@ -20,6 +20,9 @@ import os
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
 
+# CNN2SNN imports
+from cnn2snn import load_quantized_model
+
 from .preprocessing import load_labels_mapping, load_columns_type
 from ..tabular_data.tabular_data import create_tse, create_mlp
 
@@ -67,29 +70,6 @@ def tse_mlp_cse2018(numerical_columns=None,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    # Check weights
-    if not (weights in {None, 'cse2018'} or os.path.exists(weights)):
-        raise ValueError('The `weights` argument should be either '
-                         '`None` (random initialization) '
-                         'or `cse2018` to load weights over http '
-                         'or the path to the weights file to be loaded.')
-
-    # Check if cse2018 pretrained weights are compatible with given arguments
-    if weights == 'cse2018':
-        quant_params = (weight_quantization, activ_quantization,
-                        input_weight_quantization)
-        if quant_params != (2, 4, 0):
-            raise ValueError(
-                "If 'weights' is 'cse2018', quantization parameters "
-                "(weight_quantization, activ_quantization, "
-                "input_weight_quantization) must be (2, 4, 0); "
-                f" got quantization parameters={quant_params}")
-        cols_params = (numerical_columns, categorical_columns)
-        if cols_params != (None, None):
-            raise ValueError(
-                "If 'weights' is 'cse2018', columns parameters "
-                "(numerical_columns, categorical_columns) must be (None, None)")
-
     labels_mappings = load_labels_mapping()
     n_classes = len(labels_mappings)
 
@@ -117,16 +97,16 @@ def tse_mlp_cse2018(numerical_columns=None,
                             activ_quantization=activ_quantization)
     model = Model(inputs=inputs, outputs=mlp_output)
 
-    # Load weights.
-    if weights == 'cse2018':
-        model_name = (f'tse_mlp_cse2018_wq{weight_quantization}'
-                      f'_aq{activ_quantization}'
-                      f'_iq{input_weight_quantization}.hdf5')
-        weights_path = get_file(fname=model_name,
-                                origin=BASE_WEIGHT_PATH + model_name,
-                                cache_subdir='models')
-        model.load_weights(weights_path)
-    elif weights is not None:
-        model.load_weights(weights)
+    # Load weights
+    if weights is not None:
+        model.load_weights(weights, by_name=True)
 
     return model
+
+
+def tse_mlp_cse2018_pretrained():
+    model_name = 'tse_mlp_cse2018_wq2_aq4_iq0.hdf5'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
\ No newline at end of file
