@@ -69,7 +69,7 @@ from tensorflow.keras.layers import (Input, BatchNormalization, MaxPool2D,
 
 # cnn2snn Imports
 from cnn2snn import (WeightQuantizer, WeightFloat, QuantizedConv2D,
-                     QuantizedSeparableConv2D)
+                     QuantizedSeparableConv2D, load_quantized_model)
 
 # Local utils
 from ..quantization_blocks import _add_activation_layer
@@ -229,34 +229,6 @@ def mobilenet_imagenet(input_shape=None,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    # Check weights
-    if not (weights in {None, 'imagenet'} or os.path.exists(weights)):
-        raise ValueError('The `weights` argument should be either '
-                         '`None` (random initialization) '
-                         'or `imagenet` to load weights over http '
-                         'or the path to the weights file to be loaded.')
-
-    # Check if imagenet pretrained weights are compatible with given arguments
-    if weights == 'imagenet':
-        quant_params = (weight_quantization, activ_quantization,
-                        input_weight_quantization)
-        if classes != 1000:
-            raise ValueError(
-                "If 'weights' is 'imagenet', classes should be 1000")
-        if quant_params != (4, 4, 8) and quant_params != (0, 0, 0):
-            raise ValueError(
-                "If 'weights' is 'imagenet', quantization parameters "
-                "(weight_quantization, activ_quantization, "
-                " input_weight_quantization) must be (4, 4, 8) or"
-                " (0, 0, 0)")
-        if input_shape[-1] != 3:
-            raise ValueError("If 'weights' is 'imagenet', channel number"
-                             " must be 3")
-        if input_shape[0] != 224 or input_shape[1] != 224:
-            print(
-                "If 'weights' is 'imagenet', weights trained for input (224, 224) "
-                "will be used")
-
     # Determine proper input shape and default size.
     if input_shape is None:
         default_size = 224
@@ -358,22 +330,25 @@ def mobilenet_imagenet(input_shape=None,
 
     # Create model.
     model = Model(img_input, x, name='mobilenet_%0.2f_%s' % (alpha, rows))
-    # Load weights.
-    if weights == 'imagenet':
-        if include_top:
-            include_top_file_name = ''
-        else:
-            include_top_file_name = '_no_top'
-        if input_weight_quantization == 0:
-            model_name = (f'mobilenet_imagenet{include_top_file_name}.h5')
-        else:
-            model_name = (f'mobilenet_imagenet_wq{weight_quantization}'
-                          f'_aq{activ_quantization}{include_top_file_name}.h5')
-        weights_path = get_file(fname=model_name,
-                                origin=BASE_WEIGHT_PATH + model_name,
-                                cache_subdir='models')
-        model.load_weights(weights_path)
-    elif weights is not None:
-        model.load_weights(weights)
+
+    # Load weights
+    if weights is not None:
+        model.load_weights(weights, by_name=True)
 
     return model
+
+
+def mobilenet_imagenet_pretrained():
+    model_name = 'mobilenet_imagenet_wq4_aq4.h5'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
+
+
+def mobilenet_cats_vs_dogs_pretrained():
+    model_name = 'mobilenet_cats_vs_dogs_wq4_aq4.h5'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
