@@ -21,6 +21,9 @@ from tensorflow.keras import Model
 from tensorflow.keras.layers import Input, Reshape, Activation
 from tensorflow.keras.utils import get_file
 
+# CNN2SNN imports
+from cnn2snn import load_quantized_model
+
 from ..quantization_blocks import conv_block, separable_conv_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/ds_cnn/'
@@ -76,35 +79,9 @@ def ds_cnn_kws(input_shape,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    # Check weights
-    if not (weights in {None, 'kws'} or os.path.exists(weights)):
-        raise ValueError('The `weights` argument should be either '
-                         '`None` (random initialization) '
-                         'or `kws` to load weights over http '
-                         'or the path to the weights file to be loaded.')
-
     if include_top and not classes:
         raise ValueError("If 'include_top' is True, 'classes' must be set.")
 
-    # Check if KWS pretrained weights are compatible with given arguments
-    if weights == 'kws':
-        if include_top and classes != 12:
-            raise ValueError(
-                "If using 'weights' as 'kws' with 'include_top' as "
-                "true, classes should be 12")
-        quant_params = (input_weight_quantization, weight_quantization,
-                        activ_quantization)
-        if quant_params != (8, 4, 4):
-            raise ValueError("If 'weights' is 'kws', quantization parameters "
-                             "(input_weight_quantization, weight_quantization"
-                             ", activ_quantization) must be (8,4,4)")
-        if input_shape[-1] != 1:
-            raise ValueError("If weights is 'kws', the input must have 1 "
-                             f"channel; got input_shape={input_shape}")
-        if tuple(input_shape) != (49, 10, 1):
-            print("'input_shape' is different from (49, 10, 1). Weights for "
-                  "input shape (49, 10, 1) will be loaded as default.")
-
     img_input = Input(shape=input_shape)
 
     x = conv_block(img_input,
@@ -187,19 +164,16 @@ def ds_cnn_kws(input_shape,
 
     model = Model(img_input, x, name='ds_cnn_kws')
 
-    # Load weights.
-    if weights == 'kws':
-        if include_top:
-            model_name = (f'ds_cnn_kws_wq{weight_quantization}'
-                          f'_aq{activ_quantization}.hdf5')
-        else:
-            model_name = (f'ds_cnn_kws_wq{weight_quantization}'
-                          f'_aq{activ_quantization}_no_top.hdf5')
-        weights_path = get_file(fname=model_name,
-                                origin=BASE_WEIGHT_PATH + model_name,
-                                cache_subdir='models')
-        model.load_weights(weights_path)
-    elif weights is not None:
-        model.load_weights(weights)
+    # Load weights
+    if weights is not None:
+        model.load_weights(weights, by_name=True)
 
     return model
+
+
+def ds_cnn_kws_pretrained():
+    model_name = 'ds_cnn_kws_wq4_aq4.hdf5'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
\ No newline at end of file
